@@ -1,4 +1,4 @@
-# $Id: simtest.R,v 1.42 2002/07/23 07:51:57 hothorn Exp $
+# $Id: simtest.R,v 1.43 2002/09/18 09:07:29 hothorn Exp $
 
 simtest <- function(y, ...) UseMethod("simtest")
 
@@ -51,7 +51,7 @@ csimtest <- function(estpar, df, covm, cmatrix=NULL, ctype="user-defined",
 {
     if (!is.vector(estpar) & !is.matrix(estpar)) stop("estpar not a vector")
     p <- length(estpar)
-    if (!is.integer(df)) stop("df not an integer")
+    if (!all.equal(df - floor(df), 0)) stop("df not an integer")
     if (!is.matrix(covm)) stop("covm is not a matrix")
     cm <- cmatrix
     if (ctype !="user-defined") cmatrix <- NULL
